#' @name MorettinA3
#' @title Séries Temporais sobre Precipitação Atmosférica
#' @description Dados sobre precipitação atmosférica em Fortaleza, Ceará
#'     e em Lavras, Minas Gerais.
#' @format Uma lista com duas séries temporais referentes a precipitação
#'     atmosférica:
#'
#' \describe{
#'
#' \item{\code{Fortaleza-CE}}{Precipitação atmosférica, em Fortaleza, no
#'     estado do Ceará. São 149 observações anuais de 1849 a 1997.}
#'
#' \item{\code{Lavras-MG}}{Precipitação atmosférica, em Lavras, no
#'     estado de Minas Gerais. São 384 observações mensais de janeiro de
#'     1966 a dezembro de 1997.}
#'
#' }
#' @keywords TS
#' @source MORETTIN, TOLOI (2006), Série A3 - Chuva, descrita no
#'     Capítulo 1 pág. 16 e mencionada em diversas páginas.
#' @examples
#'
#' data(MorettinA3)
#' str(MorettinA3)
#' MorettinA3
#'
#' # Resumos da série
#' sapply(MorettinA3, summary)
#' sapply(MorettinA3, function(x) {
#'     c("nobs" = length(x), "nobs/ano" = frequency(x))
#' })
#'
#' # Visualização das séries
#' library(lattice)
#'
#' xyplot(MorettinA3[["Fortaleza-CE"]],
#'        main = "Precipitação atmosférica em Fortaleza-CE",
#'        type = c("o", "g"),
#'        pch = 20, col = "orange")
#'
#' xyplot(MorettinA3[["Lavras-MG"]],
#'        main = "Precipitação atmosférica em Fortaleza-CE",
#'        type = c("o", "g"),
#'        pch = 20, col = "orange")
#'
NULL
