#' @name MorettinA6
#' @title Emissão Diária de Poluentes na Cidade de São Paulo em 1997
#' @description Dados sobre sobre a emissão diária de poluentes na
#'     cidade de São Paulo no ano de 1997. Foram acompanhadas cinco
#'     poluentes atmosféricos: monóxido de carbono (\eqn{CO}), dióxido
#'     de nitrogênio (NO_2), partículas inaláveis de diâmetro inferior a
#'     10 micrometros (\eqn{PM_{10}}), dióxido de enxofre (\eqn{SO_2}) e
#'     ozônio troposférico (\eqn{O_3}).
#' @format Uma série temporal multivariada (classe \code{mts}), com 365
#'     observações diárias de 1º de janeiro a 31 de dezembro de 1997,
#'     dos seguintes poluentes:
#'
#' \describe{
#'
#' \item{\code{CO}}{Monóxido de carbono, gás carbônico (\eqn{CO}).}
#'
#' \item{\code{NO2}}{Dióxido de nitrogênio (\eqn{NO2}).}
#'
#' \item{\code{PM10}}{Partículas inaláveis de diâmetro inferior a 10
#'     micrometros, material particulado (\eqn{PM_{10}}).}
#'
#' \item{\code{SO2}}{Dióxido de enxofre (\eqn{SO_2}).}
#'
#' \item{\code{O3}}{Ozônio troposférico (\eqn{O_3}).}
#'
#' }
#'
#' Para todos os poluentes as unidades de medida não foram informadas.
#' @keywords TS MTS
#' @source MORETTIN, TOLOI (2006), Série A6 - Poluição, descrita no
#'     Capítulo 1 pág. 17 e mencionada em diversas páginas.
#' @examples
#'
#' data(MorettinA6)
#' str(MorettinA6)
#' MorettinA6
#'
#' # Estatísticas pontuais das séries
#' apply(MorettinA6, 2, summary)
#'
#' # Visualização da série
#' library(lattice)
#' xyplot(MorettinA6, type = c("o", "g"), pch = 20, col = "brown")
#'
#' # Selecionando apenas as emissões de gás carbônico
#' CO <- MorettinA6[, "CO"]
#' str(CO)
#'
NULL
